@@ -188,7 +188,8 @@ def encode(im):
     * character - the glyphs for all used 8x8 characters.  One character is 16 bytes.  Type of this array is 'B' (unsigned byte)
     * palette - the 4-color palettes for all used 8x8 characters.  One character is 8 bytes.  Type of this array is 'H' (unsigned short)
 
-    These three data should be loaded into Gameduino memory in order to display the image.  For example, to encode a single image and
+    To display the image, load these three arrays into Gameduino memory.  For example,
+    to encode a single image and
     write its data to a header file ``titlescreen.h``::
 
       import gameduino.prep as gdprep
@@ -264,6 +265,8 @@ def palettize(im, ncol):
         # For a list of images, paste them all into a single image,
         # palettize the single image, then return cropped subimages
 
+        for i in im:
+            i.load()
         (ms, lpos) = glom([i.size for i in im])
         master = Image.new(im[0].mode, ms)
         for i,ps in zip(im, lpos):
@@ -273,7 +276,8 @@ def palettize(im, ncol):
         for i in ims:
             i.info = master.info
         return ims
-
+    else:
+        im.load()
         
     if im.mode == 'P':
         if ord(max(im.tostring())) < ncol:
@@ -296,12 +300,13 @@ def palettize(im, ncol):
 
 def isnonblank(im):
     assert im.mode == 'P'
-    assert 'transparency' in im.info
-
-    transparent = im.info['transparency']
-    (w,h) = im.size
-    colors = set([im.getpixel((i, j)) for i in range(w) for j in range(h)])
-    return colors != set([transparent])
+    if 'transparency' in im.info:
+        transparent = im.info['transparency']
+        (w,h) = im.size
+        colors = set([im.getpixel((i, j)) for i in range(w) for j in range(h)])
+        return colors != set([transparent])
+    else:
+        return True
 
 class ImageRAM(object):
     """
@@ -341,7 +346,7 @@ class ImageRAM(object):
         If the data would cause the ImageRAM to increase beyond 16K, this method throws exception OverflowError.
         """
         assert size in (4,16,256)
-        assert max(page) < size
+        assert max(page) < size, "%d colors allowed, but page contains %d" % (size, max(page))
         assert len(page) == 256
 
         bits = {4:2, 16:4, 256:8}[size]
@@ -404,7 +409,8 @@ class ImageRAM(object):
     {
       switch (anim) {
         """ % name
-        ncolors = ord(max(im.tostring())) + 1
+        highest = ord(max(im.tostring()))
+        ncolors = min([c for c in [4,16,256] if (highest < c)])
         for spr,spriteimage in enumerate(tiles):
             print >>self.hh, "case %d:" % spr
             for y in range((size[1] + 15) / 16):
@@ -461,4 +467,4 @@ def spectrum(specfile, cutoff = 64, volume = 255):
     samps = sum([a for (f,a) in amps])
     return [(f, int(volume * a / samps)) for (f, a) in amps]
 
-__all__ = [ "palettize", "encode", "ImageRAM", "spectrum", "dump" ]
+__all__ = [ "encode", "dump", "palettize", "getpal", "ImageRAM", "spectrum", ]
