@@ -5,7 +5,23 @@ gameduino.sim - simple simulator
 The Gameduino simulator can simulate some aspects of Gameduino hardware, both video and audio.
 It can be a useful tool for previewing media before loading on actual hardware.
 
-The Gameduino in this module is similar to the one in :mod:`gameduino.remote`.
+The Gameduino in this module is similar to the one in :mod:`gameduino.remote`::
+
+    import gameduino
+    import gameduino.prep as gdprep
+    import gameduino.sim as gdsim
+
+    im = Image.open("platformer.png").convert("RGB")
+    (pic,chr,pal) = gdprep.encode(im)
+    gd = gdsim.Gameduino()
+    gd.wrstr(gameduino.RAM_PIC, pic)
+    gd.wrstr(gameduino.RAM_CHR, chr)
+    gd.wrstr(gameduino.RAM_PAL, pal)
+    gd.im().save("preview.png")
+
+The simulator can produce screenshots (:meth:`im`), generate simulated
+single-note sounds (:meth:`writewave`), and simulate collision RAM
+(:meth:`coll`).  It does not currently simulate the coprocessor.
 
 """
 
@@ -64,6 +80,12 @@ class Gameduino(BaseGameduino):
         return self.mem[a:a+n].tostring()
 
     def writewave(self, duration, dst):
+        """
+        Write the simulated output of the sound system to a wave file
+
+        :param duration: length of clip in seconds
+        :param dst: destination wave filename
+        """
         sintab = [int(127 * math.sin(2 * math.pi * i / 128.)) for i in range(128)]
         nsamples = int(8000 * duration)
         master = [i/8000. for i in range(nsamples)]
@@ -212,7 +234,11 @@ class Gameduino(BaseGameduino):
 
     def im(self):
         """
-        Return the current screen as a 400x300 RGB PIL Image.
+        Return the current screen as a 400x300 RGB PIL Image::
+
+            >>> import gameduino.sim
+            >>> gd = gameduino.sim.Gameduino()
+            >>> gd.im().save("screenshot.png")
         """
         import Image
         fi = Image.new("RGB", (400,300))
